package com.configuracion.dao;

import java.sql.SQLException;
import java.util.HashMap;
import com.configuracion.conexion.Constantes;
import com.configuracion.conexion.GestorBD;
import com.configuracion.interfaces.ICafDao;

public class CafDao extends GestorBD implements ICafDao {

	/**
	 * Metodo que permite identificar si el CAF es MAC o es POS
	 * @param comercial --> Codigo Comercial
	 * @param ciudad --> Codigo Ciudad 
	 * @return respuesta --> Mapa con los CAF de la Ciudad que cuentan con saldo (caf, saldo)
	 */	
	public HashMap<String, Object> saldosCaf(String comercial, String ciudad) throws SQLException {
		HashMap<String, Object> respuesta = new HashMap<String, Object>();
		int i = 0;
		try {
			bd.conectar(Constantes.usuarioAuditor, Constantes.passwordAuditor, Constantes.bdAuditor);
			sql = "SELECT s.cod_caf AS codCaf, SUM(s.saldo) AS saldo " + 
				  "FROM saldos s " +
				  "INNER JOIN caf c ON (s.cod_caf = c.cod_caf) " +
				  "WHERE c.cod_municipio='"+ciudad+"' AND s.cod_comercial='"+comercial+"' AND s.saldo>0 AND s.fecha_vencimiento>current_date+7 " +
				  "GROUP BY s.cod_caf " +
				  "ORDER BY 2 DESC "; 
			resultSet = bd.ejecutar(sql);
			while (resultSet.next()){
				respuesta.put("caf_"+i, resultSet.getString("caf"));
				respuesta.put("saldo_"+i, resultSet.getString("saldo"));
				i++;
			}
			respuesta.put("cantidadRegistros",i);
		} catch (Exception e) {
            e.printStackTrace();
        } finally {
            bd.desconectar();
        }
        System.out.println("===>Saldos Caf: "+respuesta);
        return respuesta;
	}
	
	/**
	 * Metodo que permite identificar si el CAF es MAC o es POS
	 * @param caf --> Codigo CAF
	 * @return 0 --> CAF no es AltoCosto
	 * @return 1 --> CAF AltoCosto
	 */
	public int cafEsAltoCosto(String caf) throws SQLException {
		int respuesta = 0;
		try {
			bd.conectar(Constantes.usuarioAuditor, Constantes.passwordAuditor, Constantes.bdAuditor);
			sql = "SELECT COUNT(*) AS manejaAltoCosto " +
				  "FROM configuracion_caf " +
				  "WHERE cod_caf='"+caf+"' AND nombre='MANEJA ALTOCOSTO' AND valor='S'"; 
			resultSet = bd.ejecutar(sql);
			resultSet.next();
			respuesta = resultSet.getInt("manejaAltoCosto");
		} catch (Exception e) {
            e.printStackTrace();
        } finally {
            bd.desconectar();
        }
        System.out.println("===>CAF Maneja Alto Costo: "+respuesta);
        return respuesta;
	}
	
}